lilypondparsertools.LilyPondEvent
=================================

.. abjad-lineage:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent

.. autoclass:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondEvent.LilyPondEvent.LilyPondEvent.__repr__
   :noindex:
